TreMatch

Struct TreMatch 

pub struct TreMatch {
    pub start: usize,
    pub end: usize,
    pub cost: u32,
    pub n_ins: u32,
    pub n_del: u32,
    pub n_subst: u32,
}
Successful approximate-match result.

Fields

start: usize

Byte offset where the match starts. The current TRE wrapper does not request submatch storage, so this is reported as 0 on a successful match. Phase 3.1 will add submatch capture and populate the real offset.

end: usize

Byte offset one past the end of the match. See Self::start for the current limitation.

cost: u32

Total cost of the match (sum of edit costs).

n_ins: u32

Number of inserts.

n_del: u32

Number of deletes.

n_subst: u32

Number of substitutes.